@@ -197,8 +197,16 @@ class Transport(ThreadManager):
                     return None
 
         # encode sanitized payload
-        data['request']['body'] = base64.b64encode(data['request']['body'].encode('ascii')).decode()
-        data['response']['body'] = base64.b64encode(data['response']['body'].encode('ascii')).decode()
+        if isinstance(data['request']['body'], bytes):
+            data['request']['body'] = base64.b64encode(data['request']['body']).decode()
+        else:
+            data['request']['body'] = base64.b64encode(data['request']['body'].encode('utf-8')).decode()
+
+        if isinstance(data['response']['body'], bytes):
+            data['response']['body'] = base64.b64encode(data['response']['body']).decode()
+        else:
+            data['response']['body'] = base64.b64encode(data['response']['body'].encode('utf-8')).decode()
+
         data["metadata"] = {
             "platform": get_runtime_env(),
             "agent": {
